@@ -27,22 +27,22 @@ import (
 	"github.com/apache/arrow-go/v18/arrow"
 	"github.com/apache/arrow-go/v18/arrow/compute"
 	"github.com/apache/arrow-go/v18/arrow/scalar"
-	"github.com/substrait-io/substrait-go/v3/expr"
-	"github.com/substrait-io/substrait-go/v3/extensions"
-	"github.com/substrait-io/substrait-go/v3/types"
+	"github.com/substrait-io/substrait-go/v7/expr"
+	"github.com/substrait-io/substrait-go/v7/extensions"
+	"github.com/substrait-io/substrait-go/v7/types"
 )
 
 const (
-	// URI for official Arrow Substrait Extension Types
-	ArrowExtTypesUri          = "https://github.com/apache/arrow/blob/main/format/substrait/extension_types.yaml"
-	SubstraitDefaultURIPrefix = extensions.SubstraitDefaultURIPrefix
-	// URI for official Substrait Arithmetic funcs extensions
-	SubstraitArithmeticFuncsURI = SubstraitDefaultURIPrefix + "functions_arithmetic.yaml"
-	// URI for official Substrait Comparison funcs extensions
-	SubstraitComparisonFuncsURI = SubstraitDefaultURIPrefix + "functions_comparison.yaml"
-	SubstraitBooleanFuncsURI    = SubstraitDefaultURIPrefix + "functions_boolean.yaml"
+	// URN for official Arrow Substrait Extension Types
+	ArrowExtTypesUrn          = "https://github.com/apache/arrow/blob/main/format/substrait/extension_types.yaml"
+	SubstraitDefaultURIPrefix = extensions.SubstraitDefaultURNPrefix
+	// URN for official Substrait Arithmetic funcs extensions
+	SubstraitArithmeticFuncsURI = SubstraitDefaultURIPrefix + "functions_arithmetic"
+	// URN for official Substrait Comparison funcs extensions
+	SubstraitComparisonFuncsURI = SubstraitDefaultURIPrefix + "functions_comparison"
+	SubstraitBooleanFuncsURI    = SubstraitDefaultURIPrefix + "functions_boolean"
 
-	SubstraitIcebergSetFuncURI = "https://github.com/apache/iceberg-go/blob/main/table/substrait/functions_set.yaml"
+	SubstraitIcebergSetFuncURN = "extension:apache.iceberg:functions_set"
 	TimestampTzTimezone        = "UTC"
 )
 
@@ -72,7 +72,7 @@ func init() {
 
 	for _, t := range types {
 		err := DefaultExtensionIDRegistry.RegisterType(extensions.ID{
-			URI: ArrowExtTypesUri, Name: t.name}, t.dt)
+			URN: ArrowExtTypesUrn, Name: t.name}, t.dt)
 		if err != nil {
 			panic(err)
 		}
@@ -80,7 +80,7 @@ func init() {
 
 	for _, fn := range []string{"add", "subtract", "multiply", "divide", "power", "sqrt", "abs"} {
 		err := DefaultExtensionIDRegistry.AddSubstraitScalarToArrow(
-			extensions.ID{URI: SubstraitArithmeticFuncsURI, Name: fn},
+			extensions.ID{URN: SubstraitArithmeticFuncsURI, Name: fn},
 			decodeOptionlessOverflowableArithmetic(fn))
 		if err != nil {
 			panic(err)
@@ -90,7 +90,7 @@ func init() {
 	for _, fn := range []string{"add", "subtract", "multiply", "divide"} {
 		err := DefaultExtensionIDRegistry.AddArrowToSubstrait(fn,
 			encodeOptionlessOverflowableArithmetic(extensions.ID{
-				URI: SubstraitArithmeticFuncsURI, Name: fn}))
+				URN: SubstraitArithmeticFuncsURI, Name: fn}))
 		if err != nil {
 			panic(err)
 		}
@@ -98,7 +98,7 @@ func init() {
 
 	for _, fn := range []string{"equal", "not_equal", "lt", "lte", "gt", "gte", "is_null", "is_not_null", "is_nan"} {
 		err := DefaultExtensionIDRegistry.AddSubstraitScalarToArrow(
-			extensions.ID{URI: SubstraitComparisonFuncsURI, Name: fn},
+			extensions.ID{URN: SubstraitComparisonFuncsURI, Name: fn},
 			simpleMapSubstraitToArrowFunc)
 		if err != nil {
 			panic(err)
@@ -115,7 +115,7 @@ func init() {
 
 	for _, fn := range []string{"and", "or", "not"} {
 		err := DefaultExtensionIDRegistry.AddSubstraitScalarToArrow(
-			extensions.ID{URI: SubstraitBooleanFuncsURI, Name: fn},
+			extensions.ID{URN: SubstraitBooleanFuncsURI, Name: fn},
 			simpleMapSubstraitToArrowFunc)
 		if err != nil {
 			panic(err)
@@ -132,7 +132,7 @@ func init() {
 
 	for _, fn := range []string{"is_in"} {
 		err := DefaultExtensionIDRegistry.AddSubstraitScalarToArrow(
-			extensions.ID{URI: SubstraitIcebergSetFuncURI, Name: fn},
+			extensions.ID{URN: SubstraitIcebergSetFuncURN, Name: fn},
 			setLookupFuncSubstraitToArrowFunc)
 		if err != nil {
 			panic(err)
@@ -244,13 +244,13 @@ func simpleMapSubstraitToArrowFunc(sf *expr.ScalarFunction, input []compute.Datu
 	return
 }
 
-func simpleMapArrowToSubstraitFunc(uri string) arrowToSubstrait {
+func simpleMapArrowToSubstraitFunc(urn string) arrowToSubstrait {
 	return func(fname string) (extensions.ID, []*types.FunctionOption, error) {
 		f, ok := arrowToSubstraitFuncMap[fname]
 		if ok {
 			fname = f
 		}
-		return extensions.ID{URI: uri, Name: fname}, nil, nil
+		return extensions.ID{URN: urn, Name: fname}, nil, nil
 	}
 }
 
@@ -320,9 +320,9 @@ func (e *extensionSet) GetArrowRegistry() *ExtensionIDRegistry       { return e.
 func (e *extensionSet) GetSubstraitRegistry() expr.ExtensionRegistry { return e.ExtensionRegistry }
 
 func (e *extensionSet) DecodeTypeArrow(anchor uint32) (extensions.ID, arrow.DataType, bool) {
-	id, ok := e.Set.DecodeType(anchor)
+	id, ok := e.DecodeType(anchor)
 	if !ok {
-		if id, ok = e.Set.DecodeTypeVariation(anchor); !ok {
+		if id, ok = e.DecodeTypeVariation(anchor); !ok {
 			return id, nil, false
 		}
 	}
@@ -332,7 +332,7 @@ func (e *extensionSet) DecodeTypeArrow(anchor uint32) (extensions.ID, arrow.Data
 }
 
 func (e *extensionSet) DecodeFunction(ref uint32) (extensions.ID, substraitToArrow, bool) {
-	id, ok := e.Set.DecodeFunc(ref)
+	id, ok := e.DecodeFunc(ref)
 	if !ok {
 		return id, nil, false
 	}
@@ -353,7 +353,7 @@ func (e *extensionSet) EncodeTypeVariation(dt arrow.DataType) (extensions.ID, ui
 		return extensions.ID{}, 0, false
 	}
 
-	return id, e.Set.GetTypeVariationAnchor(id), true
+	return id, e.GetTypeVariationAnchor(id), true
 }
 
 func (e *extensionSet) EncodeType(dt arrow.DataType) (extensions.ID, uint32, bool) {
@@ -362,11 +362,11 @@ func (e *extensionSet) EncodeType(dt arrow.DataType) (extensions.ID, uint32, boo
 		return extensions.ID{}, 0, false
 	}
 
-	return id, e.Set.GetTypeAnchor(id), true
+	return id, e.GetTypeAnchor(id), true
 }
 
 func (e *extensionSet) EncodeFunction(id extensions.ID) uint32 {
-	return e.Set.GetFuncAnchor(id)
+	return e.GetFuncAnchor(id)
 }
 
 // ExtensionIDRegistry manages a set of mappings between Arrow types
@@ -540,6 +540,10 @@ func FieldsFromSubstrait(typeList []types.Type, nextName func() string, ext Exte
 	return
 }
 
+func substraitToArrowTimeUnit(in types.TimePrecision) arrow.TimeUnit {
+	return arrow.TimeUnit(in / 3)
+}
+
 // ToSubstraitType converts an arrow data type to a Substrait Type. Since
 // arrow types don't have a nullable flag (it is in the arrow.Field) but
 // Substrait types do, the nullability must be passed in here.
@@ -691,6 +695,32 @@ func ToSubstraitType(dt arrow.DataType, nullable bool, ext ExtensionIDSet) (type
 			Key:         keyType,
 			Value:       valueType,
 		}, nil
+	case arrow.TIME32:
+		unit := dt.(*arrow.Time32Type).Unit
+		return &types.PrecisionTimeType{
+			Nullability: nullability,
+			Precision:   types.TimePrecision(unit * 3),
+		}, nil
+	case arrow.TIME64:
+		unit := dt.(*arrow.Time64Type).Unit
+		return &types.PrecisionTimeType{
+			Nullability: nullability,
+			Precision:   types.TimePrecision(unit * 3),
+		}, nil
+	case arrow.TIMESTAMP:
+		dt := dt.(*arrow.TimestampType)
+		if dt.TimeZone != "" {
+			return &types.PrecisionTimestampTzType{
+				PrecisionTimestampType: types.PrecisionTimestampType{
+					Nullability: nullability,
+					Precision:   types.TimePrecision(dt.Unit * 3),
+				},
+			}, nil
+		}
+		return &types.PrecisionTimestampType{
+			Nullability: nullability,
+			Precision:   types.TimePrecision(dt.Unit * 3),
+		}, nil
 	}
 
 	return nil, arrow.ErrNotImplemented
@@ -729,6 +759,43 @@ func FromSubstraitType(t types.Type, ext ExtensionIDSet) (arrow.DataType, bool,
 		return arrow.BinaryTypes.String, nullable, nil
 	case *types.BinaryType:
 		return arrow.BinaryTypes.Binary, nullable, nil
+	case *types.PrecisionTimeType:
+		switch t.Precision {
+		case types.PrecisionSeconds:
+			return &arrow.Time32Type{Unit: arrow.Second}, nullable, nil
+		case types.PrecisionMilliSeconds:
+			return &arrow.Time32Type{Unit: arrow.Millisecond}, nullable, nil
+		case types.PrecisionMicroSeconds:
+			return &arrow.Time64Type{Unit: arrow.Microsecond}, nullable, nil
+		case types.PrecisionNanoSeconds:
+			return &arrow.Time64Type{Unit: arrow.Nanosecond}, nullable, nil
+		}
+	case *types.PrecisionTimestampType:
+		switch t.Precision {
+		case types.PrecisionSeconds:
+			return &arrow.TimestampType{Unit: arrow.Second}, nullable, nil
+		case types.PrecisionMilliSeconds:
+			return &arrow.TimestampType{Unit: arrow.Millisecond}, nullable, nil
+		case types.PrecisionMicroSeconds:
+			return &arrow.TimestampType{Unit: arrow.Microsecond}, nullable, nil
+		case types.PrecisionNanoSeconds:
+			return &arrow.TimestampType{Unit: arrow.Nanosecond}, nullable, nil
+		}
+	case *types.PrecisionTimestampTzType:
+		switch t.Precision {
+		case types.PrecisionSeconds:
+			return &arrow.TimestampType{Unit: arrow.Second, TimeZone: TimestampTzTimezone},
+				nullable, nil
+		case types.PrecisionMilliSeconds:
+			return &arrow.TimestampType{Unit: arrow.Millisecond, TimeZone: TimestampTzTimezone},
+				nullable, nil
+		case types.PrecisionMicroSeconds:
+			return &arrow.TimestampType{Unit: arrow.Microsecond, TimeZone: TimestampTzTimezone},
+				nullable, nil
+		case types.PrecisionNanoSeconds:
+			return &arrow.TimestampType{Unit: arrow.Nanosecond, TimeZone: TimestampTzTimezone},
+				nullable, nil
+		}
 	case *types.TimestampType:
 		return &arrow.TimestampType{Unit: arrow.Microsecond}, nullable, nil
 	case *types.TimestampTzType:
