@@ -30,6 +30,7 @@ import (
 	"github.com/apache/arrow-go/v18/arrow/compute"
 	"github.com/apache/arrow-go/v18/arrow/compute/exec"
 	"github.com/apache/arrow-go/v18/arrow/compute/internal/kernels"
+	"github.com/apache/arrow-go/v18/arrow/extensions"
 	"github.com/apache/arrow-go/v18/arrow/internal/testing/gen"
 	"github.com/apache/arrow-go/v18/arrow/memory"
 	"github.com/apache/arrow-go/v18/arrow/scalar"
@@ -263,6 +264,20 @@ func simpleArrArrCompare[T arrow.NumericType | string](mem memory.Allocator, op
 	return compute.NewDatum(result)
 }
 
+type BooleanCompareSuite struct {
+	CompareSuite
+}
+
+func (b *BooleanCompareSuite) TestBooleanBasics() {
+	var (
+		example1JSON = `[true, false, true, false]`
+		example2JSON = `[true, false, false, true]`
+	)
+
+	b.validateCompare(kernels.CmpEQ, arrow.FixedWidthTypes.Boolean, example1JSON, example2JSON, `[true, true, false, false]`)
+	b.validateCompare(kernels.CmpNE, arrow.FixedWidthTypes.Boolean, example1JSON, example2JSON, `[false, false, true, true]`)
+}
+
 type NumericCompareSuite[T arrow.NumericType] struct {
 	CompareSuite
 }
@@ -1194,7 +1209,7 @@ func (c *CompareStringSuite) validateCompareComputed(op kernels.CompareOperator,
 	}
 
 	defer expected.Release()
-	c.CompareSuite.validateCompareDatum(op, lhs, rhs, expected)
+	c.validateCompareDatum(op, lhs, rhs, expected)
 }
 
 func (c *CompareStringSuite) TestRandomCompareArrayArray() {
@@ -1223,6 +1238,7 @@ func (c *CompareStringSuite) TestRandomCompareArrayArray() {
 }
 
 func TestComparisons(t *testing.T) {
+	suite.Run(t, new(BooleanCompareSuite))
 	suite.Run(t, new(NumericCompareSuite[int8]))
 	suite.Run(t, new(NumericCompareSuite[int16]))
 	suite.Run(t, new(NumericCompareSuite[int32]))
@@ -1289,6 +1305,7 @@ func TestCompareKernelsDispatchBest(t *testing.T) {
 			&arrow.Decimal128Type{Precision: 3, Scale: 2}, &arrow.Decimal128Type{Precision: 21, Scale: 2}},
 		{arrow.PrimitiveTypes.Int64, &arrow.Decimal128Type{Precision: 3, Scale: 2},
 			&arrow.Decimal128Type{Precision: 21, Scale: 2}, &arrow.Decimal128Type{Precision: 3, Scale: 2}},
+		{extensions.NewUUIDType(), extensions.NewUUIDType(), &arrow.FixedSizeBinaryType{ByteWidth: 16}, &arrow.FixedSizeBinaryType{ByteWidth: 16}},
 	}
 
 	for _, name := range []string{"equal", "not_equal", "less", "less_equal", "greater", "greater_equal"} {
@@ -1495,8 +1512,8 @@ func (sv *ScalarValiditySuite) TestIsNaN() {
 	}{
 		{`[]`, `[]`},
 		{`[1]`, `[false]`},
-		{`[null]`, `[null]`},
-		{`["NaN", 1, 0, null]`, `[true, false, false, null]`},
+		{`[null]`, `[false]`},
+		{`["NaN", 1, 0, null]`, `[true, false, false, false]`},
 	}
 
 	for _, typ := range floatingTypes {
