@@ -166,10 +166,10 @@ func makeDateTypeTable(mem memory.Allocator, expected bool, partialDays bool) ar
 		bldr.Field(0).(*array.Date64Builder).AppendValues(d64Values, isValid)
 	}
 
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
-	return array.NewTableFromRecords(arrsc, []arrow.Record{rec})
+	return array.NewTableFromRecords(arrsc, []arrow.RecordBatch{rec})
 }
 
 func makeTimestampTypeTable(mem memory.Allocator, expected bool) arrow.Table {
@@ -201,10 +201,10 @@ func makeTimestampTypeTable(mem memory.Allocator, expected bool) arrow.Table {
 	bldr.Field(0).(*array.TimestampBuilder).AppendValues(ts64msValues, isValid)
 	bldr.Field(1).(*array.TimestampBuilder).AppendValues(ts64msValues, isValid)
 
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
-	return array.NewTableFromRecords(arrsc, []arrow.Record{rec})
+	return array.NewTableFromRecords(arrsc, []arrow.RecordBatch{rec})
 }
 
 func TestWriteArrowCols(t *testing.T) {
@@ -448,7 +448,7 @@ func TestWriteKeyValueMetadata(t *testing.T) {
 		b.AppendNull()
 	}
 
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
 	props := parquet.NewWriterProperties(
@@ -493,7 +493,7 @@ func TestWriteEmptyLists(t *testing.T) {
 		b.AppendNull()
 	}
 
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
 	props := parquet.NewWriterProperties(
@@ -532,7 +532,7 @@ func TestWriteAllNullsWithDeltaEncoding(t *testing.T) {
 		b.AppendNull()
 	}
 
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
 	props := parquet.NewWriterProperties(
@@ -1284,6 +1284,30 @@ func (ps *ParquetIOTestSuite) writeColumn(mem memory.Allocator, sc *schema.Group
 	return buf.Bytes()
 }
 
+func (ps *ParquetIOTestSuite) writeDictionaryColumn(mem memory.Allocator, sc *schema.GroupNode, values arrow.Array) []byte {
+	var buf bytes.Buffer
+	arrsc, err := pqarrow.FromParquet(schema.NewSchema(sc), nil, nil)
+	ps.NoError(err)
+
+	writer, err := pqarrow.NewFileWriter(
+		arrsc,
+		&buf,
+		parquet.NewWriterProperties(
+			parquet.WithDictionaryDefault(true),
+			parquet.WithStats(true),
+		),
+		pqarrow.NewArrowWriterProperties(pqarrow.WithAllocator(mem)),
+	)
+	ps.NoError(err)
+
+	writer.NewRowGroup()
+	ps.NoError(writer.WriteColumnData(values))
+	ps.NoError(writer.Close())
+	ps.NoError(writer.Close())
+
+	return buf.Bytes()
+}
+
 func (ps *ParquetIOTestSuite) readAndCheckSingleColumnFile(mem memory.Allocator, data []byte, values arrow.Array) {
 	reader := ps.createReader(mem, data)
 	cr, err := reader.GetColumn(context.TODO(), 0)
@@ -1327,6 +1351,27 @@ var fullTypeList = []arrow.DataType{
 	&arrow.Decimal128Type{Precision: 38, Scale: 37},
 }
 
+var dictEncodingSupportedTypeList = []arrow.DataType{
+	arrow.PrimitiveTypes.Int8,
+	arrow.PrimitiveTypes.Uint8,
+	arrow.PrimitiveTypes.Int16,
+	arrow.PrimitiveTypes.Uint16,
+	arrow.PrimitiveTypes.Int32,
+	arrow.PrimitiveTypes.Int64,
+	arrow.PrimitiveTypes.Float32,
+	arrow.PrimitiveTypes.Float64,
+	arrow.BinaryTypes.String,
+	arrow.BinaryTypes.Binary,
+	&arrow.FixedSizeBinaryType{ByteWidth: 10},
+	&arrow.Decimal128Type{Precision: 1, Scale: 0},
+	&arrow.Decimal128Type{Precision: 5, Scale: 4},
+	&arrow.Decimal128Type{Precision: 10, Scale: 9},
+	&arrow.Decimal128Type{Precision: 19, Scale: 18},
+	&arrow.Decimal128Type{Precision: 23, Scale: 22},
+	&arrow.Decimal128Type{Precision: 27, Scale: 26},
+	&arrow.Decimal128Type{Precision: 38, Scale: 37},
+}
+
 func (ps *ParquetIOTestSuite) TestSingleColumnRequiredWrite() {
 	for _, dt := range fullTypeList {
 		ps.Run(dt.Name(), func() {
@@ -1826,6 +1871,37 @@ func (ps *ParquetIOTestSuite) TestFixedSizeList() {
 	ps.roundTripTable(mem, tbl, true)
 }
 
+// TestFixedSizeListNullableElements verifies that FixedSizeList with nullable
+// element type correctly round-trips non-null values through Parquet.
+// This is a regression test for https://github.com/apache/arrow-go/issues/584
+func (ps *ParquetIOTestSuite) TestFixedSizeListNullableElements() {
+	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
+	defer mem.AssertSize(ps.T(), 0)
+
+	// FixedSizeList<float32>[8] with nullable elements (the default)
+	bldr := array.NewFixedSizeListBuilder(mem, 8, arrow.PrimitiveTypes.Float32)
+	defer bldr.Release()
+
+	vb := bldr.ValueBuilder().(*array.Float32Builder)
+
+	// Single row with non-null values [1, 2, 3, 4, 5, 6, 7, 8]
+	bldr.Append(true)
+	vb.AppendValues([]float32{1, 2, 3, 4, 5, 6, 7, 8}, nil)
+
+	data := bldr.NewArray()
+	defer data.Release()
+
+	field := arrow.Field{Name: "embedding", Type: data.DataType(), Nullable: true}
+	cnk := arrow.NewChunked(field.Type, []arrow.Array{data})
+	defer data.Release()
+
+	tbl := array.NewTable(arrow.NewSchema([]arrow.Field{field}, nil), []arrow.Column{*arrow.NewColumn(field, cnk)}, -1)
+	defer cnk.Release()
+	defer tbl.Release()
+
+	ps.roundTripTable(mem, tbl, true)
+}
+
 func (ps *ParquetIOTestSuite) TestNull() {
 	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
 	defer mem.AssertSize(ps.T(), 0)
@@ -1945,6 +2021,53 @@ func TestParquetArrowIO(t *testing.T) {
 	suite.Run(t, new(ParquetIOTestSuite))
 }
 
+func TestForceLargeTypes(t *testing.T) {
+	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
+	defer mem.AssertSize(t, 0)
+
+	sc := arrow.NewSchema([]arrow.Field{
+		{Name: "str", Type: arrow.BinaryTypes.LargeString},
+		{Name: "bin", Type: arrow.BinaryTypes.LargeBinary},
+	}, nil)
+
+	bldr := array.NewRecordBuilder(mem, sc)
+	defer bldr.Release()
+
+	bldr.Field(0).(*array.LargeStringBuilder).AppendValues([]string{"hello", "foo", "bar"}, nil)
+	bldr.Field(1).(*array.BinaryBuilder).AppendValues([][]byte{[]byte("hello"), []byte("foo"), []byte("bar")}, nil)
+
+	rec := bldr.NewRecordBatch()
+	defer rec.Release()
+
+	var buf bytes.Buffer
+	wr, err := pqarrow.NewFileWriter(sc, &buf,
+		parquet.NewWriterProperties(),
+		pqarrow.NewArrowWriterProperties(pqarrow.WithAllocator(mem)))
+	require.NoError(t, err)
+
+	require.NoError(t, wr.Write(rec))
+	require.NoError(t, wr.Close())
+
+	rdr, err := file.NewParquetReader(bytes.NewReader(buf.Bytes()))
+	require.NoError(t, err)
+	defer rdr.Close()
+
+	props := pqarrow.ArrowReadProperties{}
+	props.SetForceLarge(0, true)
+	props.SetForceLarge(1, true)
+	pqrdr, err := pqarrow.NewFileReader(rdr, props, mem)
+	require.NoError(t, err)
+
+	recrdr, err := pqrdr.GetRecordReader(context.Background(), nil, nil)
+	require.NoError(t, err)
+	defer recrdr.Release()
+
+	got, err := recrdr.Read()
+	require.NoError(t, err)
+
+	assert.Truef(t, array.RecordEqual(rec, got), "expected: %s\ngot: %s", rec, got)
+}
+
 func TestBufferedRecWrite(t *testing.T) {
 	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
 	defer mem.AssertSize(t, 0)
@@ -1967,7 +2090,7 @@ func TestBufferedRecWrite(t *testing.T) {
 		array.NewStructData(structData),
 	}
 
-	rec := array.NewRecord(sc, cols, SIZELEN)
+	rec := array.NewRecordBatch(sc, cols, SIZELEN)
 	defer rec.Release()
 
 	var (
@@ -2057,6 +2180,7 @@ func (ps *ParquetIOTestSuite) TestArrowExtensionTypeRoundTrip() {
 	defer tbl.Release()
 
 	ps.roundTripTable(mem, tbl, true)
+	ps.roundTripTable(mem, tbl, false)
 }
 
 func (ps *ParquetIOTestSuite) TestArrowUnknownExtensionTypeRoundTrip() {
@@ -2164,7 +2288,7 @@ func (ps *ParquetIOTestSuite) TestArrowExtensionTypeLogicalType() {
 
 	bldr.Field(0).(*extensions.UUIDBuilder).Append(uuid.New())
 	bldr.Field(1).(*array.ExtensionBuilder).AppendValueFromString(`{"hello": ["world", 2, true], "world": null}`)
-	rec := bldr.NewRecord()
+	rec := bldr.NewRecordBatch()
 	defer rec.Release()
 
 	var buf bytes.Buffer
@@ -2212,7 +2336,7 @@ func TestWriteTableMemoryAllocation(t *testing.T) {
 	abld.ValueBuilder().(*array.Int64Builder).Append(2)
 	bld.Field(4).(*extensions.UUIDBuilder).Append(uuid.MustParse("00000000-0000-0000-0000-000000000001"))
 
-	rec := bld.NewRecord()
+	rec := bld.NewRecordBatch()
 	bld.Release()
 
 	var buf bytes.Buffer
@@ -2230,14 +2354,16 @@ func TestWriteTableMemoryAllocation(t *testing.T) {
 
 func TestEmptyListDeltaBinaryPacked(t *testing.T) {
 	schema := arrow.NewSchema([]arrow.Field{
-		{Name: "ts", Type: arrow.ListOf(arrow.PrimitiveTypes.Uint64),
+		{Name: "ts", Type: arrow.ListOfField(
+			arrow.Field{Name: "list", Type: arrow.PrimitiveTypes.Uint64, Nullable: true,
+				Metadata: arrow.NewMetadata([]string{"PARQUET:field_id"}, []string{"-1"})}),
 			Metadata: arrow.NewMetadata([]string{"PARQUET:field_id"}, []string{"-1"})}}, nil)
 	builder := array.NewRecordBuilder(memory.DefaultAllocator, schema)
 	defer builder.Release()
 
 	listBuilder := builder.Field(0).(*array.ListBuilder)
 	listBuilder.Append(true)
-	arrowRec := builder.NewRecord()
+	arrowRec := builder.NewRecordBatch()
 	defer arrowRec.Release()
 
 	var buf bytes.Buffer
@@ -2264,3 +2390,107 @@ func TestEmptyListDeltaBinaryPacked(t *testing.T) {
 	assert.True(t, schema.Equal(tbl.Schema()))
 	assert.EqualValues(t, 1, tbl.NumRows())
 }
+
+func TestReadWriteNonShreddedVariant(t *testing.T) {
+	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
+	defer mem.AssertSize(t, 0)
+
+	bldr := extensions.NewVariantBuilder(mem, extensions.NewDefaultVariantType())
+	defer bldr.Release()
+
+	jsonData := `[
+			42,
+			"text",
+			[1, 2, 3],
+			{"name": "Alice"},
+			[{"id": 1, "name": "Item 1"}, {"id": 2, "name": "Item 2"}],
+			{"items": [1, "two", true], "metadata": {"created": "2025-01-01"}},
+			null
+		]`
+
+	err := bldr.UnmarshalJSON([]byte(jsonData))
+	require.NoError(t, err)
+
+	arr := bldr.NewArray()
+	defer arr.Release()
+
+	rec := array.NewRecordBatch(arrow.NewSchema([]arrow.Field{
+		{Name: "variant", Type: arr.DataType(), Nullable: true},
+	}, nil), []arrow.Array{arr}, -1)
+
+	var buf bytes.Buffer
+	wr, err := pqarrow.NewFileWriter(rec.Schema(), &buf, nil,
+		pqarrow.DefaultWriterProps())
+	require.NoError(t, err)
+
+	require.NoError(t, wr.Write(rec))
+	rec.Release()
+	wr.Close()
+
+	rdr, err := file.NewParquetReader(bytes.NewReader(buf.Bytes()))
+	require.NoError(t, err)
+	reader, err := pqarrow.NewFileReader(rdr, pqarrow.ArrowReadProperties{}, memory.DefaultAllocator)
+	require.NoError(t, err)
+	defer rdr.Close()
+
+	tbl, err := reader.ReadTable(context.Background())
+	require.NoError(t, err)
+	defer tbl.Release()
+
+	assert.True(t, array.Equal(arr, tbl.Column(0).Data().Chunk(0)))
+}
+
+func TestReadWriteShreddedVariant(t *testing.T) {
+	vt := extensions.NewShreddedVariantType(arrow.StructOf(
+		arrow.Field{Name: "event_type", Type: arrow.BinaryTypes.String},
+		arrow.Field{Name: "event_ts", Type: arrow.FixedWidthTypes.Timestamp_us}))
+
+	mem := memory.NewCheckedAllocator(memory.DefaultAllocator)
+	defer mem.AssertSize(t, 0)
+
+	bldr := vt.NewBuilder(mem)
+	defer bldr.Release()
+
+	jsonData := `[
+			{"event_type": "noop", "event_ts": "1970-01-21 00:29:54.114937Z"},
+			42,
+			{"event_type": "text", "event_ts": "1970-01-21 00:29:54.954163Z"},
+			{"event_type": "list", "event_ts": "1970-01-21 00:29:54.240241Z"},
+			"text",
+			{"event_type": "object", "event_ts": "1970-01-21 00:29:54.146402Z"},			
+			null
+		]`
+
+	err := bldr.UnmarshalJSON([]byte(jsonData))
+	require.NoError(t, err)
+
+	arr := bldr.NewArray()
+	defer arr.Release()
+
+	rec := array.NewRecordBatch(arrow.NewSchema([]arrow.Field{
+		{Name: "variant", Type: arr.DataType(), Nullable: true},
+	}, nil), []arrow.Array{arr}, -1)
+
+	var buf bytes.Buffer
+	wr, err := pqarrow.NewFileWriter(rec.Schema(), &buf,
+		parquet.NewWriterProperties(parquet.WithDictionaryDefault(false)),
+		pqarrow.DefaultWriterProps())
+	require.NoError(t, err)
+
+	require.NoError(t, wr.Write(rec))
+	rec.Release()
+	wr.Close()
+
+	rdr, err := file.NewParquetReader(bytes.NewReader(buf.Bytes()))
+	require.NoError(t, err)
+	reader, err := pqarrow.NewFileReader(rdr, pqarrow.ArrowReadProperties{}, memory.DefaultAllocator)
+	require.NoError(t, err)
+	defer rdr.Close()
+
+	tbl, err := reader.ReadTable(context.Background())
+	require.NoError(t, err)
+	defer tbl.Release()
+
+	assert.Truef(t, array.Equal(arr, tbl.Column(0).Data().Chunk(0)),
+		"expected: %s\ngot: %s", arr, tbl.Column(0).Data().Chunk(0))
+}
