@@ -242,7 +242,7 @@ func repFromNullable(isnullable bool) parquet.Repetition {
 }
 
 func variantToNode(t *extensions.VariantType, field arrow.Field, props *parquet.WriterProperties, arrProps ArrowWriterProperties) (schema.Node, error) {
-	fields := make(schema.FieldList, 2, 3)
+	fields := make(schema.FieldList, 1, 3)
 	var err error
 
 	fields[0], err = fieldToNode("metadata", t.Metadata(), props, arrProps)
@@ -250,9 +250,12 @@ func variantToNode(t *extensions.VariantType, field arrow.Field, props *parquet.
 		return nil, err
 	}
 
-	fields[1], err = fieldToNode("value", t.Value(), props, arrProps)
-	if err != nil {
-		return nil, err
+	if value := t.Value(); value.Type != nil {
+		valueField, err := fieldToNode("value", value, props, arrProps)
+		if err != nil {
+			return nil, err
+		}
+		fields = append(fields, valueField)
 	}
 
 	if typed := t.TypedValue(); typed.Type != nil {
@@ -594,8 +597,9 @@ func getParquetType(typ arrow.DataType, props *parquet.WriterProperties, arrprop
 		precision := int(dectype.GetPrecision())
 		scale := int(dectype.GetScale())
 
+		logicalType := schema.NewDecimalLogicalType(int32(precision), int32(scale))
 		if !props.StoreDecimalAsInteger() || precision > 18 {
-			return parquet.Types.FixedLenByteArray, schema.NewDecimalLogicalType(int32(precision), int32(scale)), int(DecimalSize(int32(precision))), nil
+			return parquet.Types.FixedLenByteArray, logicalType, int(DecimalSize(int32(precision))), nil
 		}
 
 		pqType := parquet.Types.Int32
@@ -603,7 +607,7 @@ func getParquetType(typ arrow.DataType, props *parquet.WriterProperties, arrprop
 			pqType = parquet.Types.Int64
 		}
 
-		return pqType, schema.NoLogicalType{}, -1, nil
+		return pqType, logicalType, -1, nil
 	case arrow.DATE32:
 		return parquet.Types.Int32, schema.DateLogicalType{}, -1, nil
 	case arrow.DATE64:
@@ -612,14 +616,14 @@ func getParquetType(typ arrow.DataType, props *parquet.WriterProperties, arrprop
 		pqType, logicalType, err := getTimestampMeta(typ.(*arrow.TimestampType), props, arrprops)
 		return pqType, logicalType, -1, err
 	case arrow.TIME32:
-		return parquet.Types.Int32, schema.NewTimeLogicalType(true, schema.TimeUnitMillis), -1, nil
+		return parquet.Types.Int32, schema.NewTimeLogicalType(false, schema.TimeUnitMillis), -1, nil
 	case arrow.TIME64:
 		pqTimeUnit := schema.TimeUnitMicros
 		if typ.(*arrow.Time64Type).Unit == arrow.Nanosecond {
 			pqTimeUnit = schema.TimeUnitNanos
 		}
 
-		return parquet.Types.Int64, schema.NewTimeLogicalType(true, pqTimeUnit), -1, nil
+		return parquet.Types.Int64, schema.NewTimeLogicalType(false, pqTimeUnit), -1, nil
 	case arrow.FLOAT16:
 		return parquet.Types.FixedLenByteArray, schema.Float16LogicalType{}, arrow.Float16SizeBytes, nil
 	case arrow.EXTENSION:
@@ -681,7 +685,7 @@ func listToSchemaField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx *s
 
 	currentLevels.Increment(n)
 
-	out.Children = make([]SchemaField, n.NumFields())
+	out.Children = makeSchemaFields(n.NumFields())
 	ctx.LinkParent(out, parent)
 	ctx.LinkParent(&out.Children[0], out)
 
@@ -770,7 +774,7 @@ func listToSchemaField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx *s
 
 func groupToStructField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx *schemaTree, out *SchemaField) error {
 	arrowFields := make([]arrow.Field, 0, n.NumFields())
-	out.Children = make([]SchemaField, n.NumFields())
+	out.Children = makeSchemaFields(n.NumFields())
 
 	for i := 0; i < n.NumFields(); i++ {
 		if err := nodeToSchemaField(n.Field(i), currentLevels, ctx, out, &out.Children[i]); err != nil {
@@ -821,10 +825,10 @@ func mapToSchemaField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx *sc
 
 	currentLevels.Increment(n)
 	repeatedAncestorDef := currentLevels.IncrementRepeated()
-	out.Children = make([]SchemaField, 1)
+	out.Children = makeSchemaFields(1)
 
 	kvfield := &out.Children[0]
-	kvfield.Children = make([]SchemaField, 2)
+	kvfield.Children = makeSchemaFields(2)
 
 	keyField := &kvfield.Children[0]
 	valueField := &kvfield.Children[1]
@@ -872,7 +876,7 @@ func variantToSchemaField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx
 
 	if n.RepetitionType() == parquet.Repetitions.Repeated {
 		// list of variants
-		out.Children = make([]SchemaField, 1)
+		out.Children = makeSchemaFields(1)
 		repeatedAncestorDef := currentLevels.IncrementRepeated()
 		if err := groupToStructField(n, currentLevels, ctx, &out.Children[0]); err != nil {
 			return err
@@ -921,7 +925,7 @@ func groupToSchemaField(n *schema.GroupNode, currentLevels file.LevelInfo, ctx *
 		//   r/o TYPE[0] f0
 		//   r/o TYPE[1] f1
 		// }
-		out.Children = make([]SchemaField, 1)
+		out.Children = makeSchemaFields(1)
 		repeatedAncestorDef := currentLevels.IncrementRepeated()
 		if err := groupToStructField(n, currentLevels, ctx, &out.Children[0]); err != nil {
 			return err
@@ -983,7 +987,7 @@ func nodeToSchemaField(n schema.Node, currentLevels file.LevelInfo, ctx *schemaT
 	if primitive.RepetitionType() == parquet.Repetitions.Repeated {
 		// one-level list encoding e.g. a: repeated int32;
 		repeatedAncestorDefLevel := currentLevels.IncrementRepeated()
-		out.Children = make([]SchemaField, 1)
+		out.Children = makeSchemaFields(1)
 		child := arrow.Field{Name: primitive.Name(), Type: arrowType, Nullable: false}
 		populateLeaf(colIndex, &child, currentLevels, ctx, out, &out.Children[0])
 		out.Field = &arrow.Field{Name: primitive.Name(), Type: arrow.ListOf(child.Type), Nullable: false,
@@ -1202,7 +1206,7 @@ func NewSchemaManifest(sc *schema.Schema, meta metadata.KeyValueMetadata, props
 		ColIndexToField: make(map[int]*SchemaField),
 		ChildToParent:   make(map[*SchemaField]*SchemaField),
 		descr:           sc,
-		Fields:          make([]SchemaField, sc.Root().NumFields()),
+		Fields:          makeSchemaFields(sc.Root().NumFields()),
 	}
 	ctx.props = props
 	if ctx.props == nil {
@@ -1254,3 +1258,11 @@ func FromParquet(sc *schema.Schema, props *ArrowReadProperties, kv metadata.KeyV
 	}
 	return arrow.NewSchema(fields, manifest.SchemaMeta), nil
 }
+
+func makeSchemaFields(n int) []SchemaField {
+	fields := make([]SchemaField, n)
+	for i := range fields {
+		fields[i].ColIndex = -1
+	}
+	return fields
+}
